@@ -878,6 +878,15 @@ class SequenceTests(unittest.TestCase, Util):
             self.assert_(True in a)
             self.assert_(False in a)
 
+        a = bitarray('011010000001')
+        self.assert_('1' in a)
+        self.assert_('11' in a)
+        self.assert_('111' not in a)
+        self.assert_(bitarray('00') in a)
+        self.assert_([0, 0, 0, 1] in a)
+        self.assert_((0, 0, 0, 1, 1) not in a)
+        self.assert_((0, 0, 0, 0, 2) in a)
+
 
 tests.append(SequenceTests)
 
@@ -1082,6 +1091,38 @@ class MethodTests(unittest.TestCase, Util):
             self.assertEqual(a.count(0), a.to01().count('0'))
 
 
+    def test_search(self):
+        a = bitarray('')
+        self.assertEqual(a.search(bitarray('0')), [])
+        self.assertEqual(a.search(bitarray('1')), [])
+
+        a = bitarray('1')
+        self.assertEqual(a.search(bitarray('0')), [])
+        self.assertEqual(a.search(bitarray('1')), [0])
+        self.assertEqual(a.search(bitarray('11')), [])
+
+        a = bitarray(100*'1')
+        self.assertEqual(a.search(bitarray('0')), [])
+        self.assertEqual(a.search(bitarray('1')), range(100))
+
+        a = bitarray('10011')
+        for s, res in [('0',     [1, 2]),  ('1', [0, 3, 4]),
+                       ('01',    [2]),     ('11', [3]),
+                       ('000',   []),      ('1001', [0]),
+                       ('011',   [2]),     ('0011', [1]),
+                       ('10011', [0]),     ('100111', [])]:
+            self.assertEqual(a.search(s), res)
+            b = bitarray(s)
+            self.assertEqual(a.search(b), res)
+            self.assertEqual(a.search(list(b)), res)
+            self.assertEqual(a.search(tuple(b)), res)
+
+        a = bitarray('10010101110011111001011')
+        for limit in xrange(10):
+            self.assertEqual(a.search('011', limit),
+                             [6, 11, 20][:limit])
+
+
     def test_fill(self):
         a = bitarray('')
         self.assertEqual(a.fill(), 0)
